#ifndef NT2_INCLUDE_FUNCTIONS_CHOW_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CHOW_HPP_INCLUDED

#include <nt2/gallery/include/functions/chow.hpp>

#endif
